@@ -117,8 +117,7 @@ class CommandJob(Job):
             self.read_flo = io.StringIO(
                 '# %s\n\n----- stdout -----\n%s\n\n----- stderr -----\n%s'
                 '\n\n----- exception -----\n%s'
-                % (self.definition.get('shell'), stdout.rstrip(), stderr.rstrip(),
-                   e))
+                % (self.definition, stdout.rstrip(), stderr.rstrip(), e))
 
 
 class CommandEmitterJob(Job):
@@ -143,8 +142,7 @@ class CommandEmitterJob(Job):
             self.read_flo = io.StringIO(
                 '# %s\n\n----- stdout -----\n%s\n\n----- stderr -----\n%s'
                 '\n\n----- exception -----\n%s'
-                % (self.definition.get('shell'), stdout.rstrip(), stderr.rstrip(),
-                   e))
+                % (self.definition, stdout.rstrip(), stderr.rstrip(), e))
             self.destination = '_errors/%05d' % jobid
             self.commands = []
 
